Align the columns of data frames to see where their names and types synch up
compare_table_column_types.RdAlign the columns of data frames to see where their names and types synch up
compare_table_column_types.RdAlign the columns of data frames to see where their names and types synch up